===========================
Djblets 0.8.1 Release Notes
===========================

**Release date**: May 26, 2014


djblets.configforms
===================

* Fixed the layout of the config page form title.

  The title is now wrapped in a ``<div>`` with a ``box-head`` CSS class,
  fixing styling issues and making it consistent with other templates.


djblets.extensions
==================

* Added some bullet-proofing for when extension uninitialization fails.

* Fixed race conditions in a threaded environment (such as mod_worker)
  when reloading extensions.

* Fixed extension packaging to use setuptools instead of distutils.

  This allows the usage of more advanced features like the
  :file:`MANIFEST.in` file.

* Fixed a compatibility issue with Windows when deploying media files.
  (:bug:`3367`)


JavaScript
==========

* ``modalBox`` button click handlers now respect the disabled state of
  the buttons. (:bug:`3338`)

  Patch by Salam Al-yahya.


Contributors
============

* Christian Hammond
* David Trowbridge
* Salam Al-yahya
